@@ -20,7 +20,6 @@
 
 from asyncore import dispatcher
 import wxversion, os, getopt, sys, urllib, signal, socket, string
-wxversion.select("2.8")
 import wx, time
 import webbrowser, shutil
 import threading, time, codecs
@@ -76,6 +75,14 @@ class getPlugins(threading.Thread):
 class Onglets(wx.Notebook):
 	# Classe dérivée du wx.Notebook
 	def __init__(self, parent):
+		if(os.environ["POL_OS"] == "Mac"):
+			self.fontTitle = wx.Font(14, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD, False, "", wx.FONTENCODING_DEFAULT)
+			self.caption_font = wx.Font(11, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL,False, "", wx.FONTENCODING_DEFAULT)
+		else :
+			self.fontTitle = wx.Font(12, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD, False, "", wx.FONTENCODING_DEFAULT)
+			self.caption_font = wx.Font(8, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL,False, "", wx.FONTENCODING_DEFAULT)
+		
+		
 		self.notebook = wx.Notebook.__init__(self, parent, -1)
 		self.images_onglets = wx.ImageList(16, 16)
     		self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/input-gaming.png"));
@@ -342,7 +349,7 @@ class Onglets(wx.Notebook):
 		self.FileDialog.SetWildcard("POL Packages (*.pol)|*.pol")
         	self.FileDialog.ShowModal()
         	if(self.FileDialog.GetPath() != ""):
-			if(wx.YES == wx.MessageBox(_("Are you sure you want to install: ")+self.FileDialog.GetPath()+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
+			if(wx.YES == wx.MessageBox(_("Are you sure you want to install: ").decode("utf-8")+self.FileDialog.GetPath()+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
 	      			os.system("bash \""+Variables.playonlinux_env+"/playonlinux-pkg\" -i \""+self.FileDialog.GetPath().encode('utf-8')+"\"")
 				self.LoadPlugins()
         	self.FileDialog.Destroy()
@@ -350,7 +357,7 @@ class Onglets(wx.Notebook):
 	def delete_plug(self, event):
 		self.current_plugin = self.pluginlist.GetItemText(self.pluginlist.GetSelection())
 		self.plugin_path = Variables.playonlinux_rep+"/plugins/"+self.current_plugin
-   	        if(wx.YES == wx.MessageBox(_("Are you sure you want to delete: ")+self.current_plugin+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
+   	        if(wx.YES == wx.MessageBox(_("Are you sure you want to delete: ").decode("utf-8")+self.current_plugin+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
 			shutil.rmtree(self.plugin_path)
 			self.LoadPlugins()
 	def disable(self, event):
@@ -407,7 +414,7 @@ class Onglets(wx.Notebook):
 			
 
 class MainWindow(wx.Frame):
-  def __init__(self,parent,id,title):
+  def __init__(self,parent,id,title,onglet):
     wx.Frame.__init__(self, parent, -1, title, size = (505, 550), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
     self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
     self.panelFenp = wx.Panel(self, -1)
@@ -420,13 +427,15 @@ class MainWindow(wx.Frame):
     self.sizer.Add(self.onglets, 10, wx.EXPAND|wx.ALL, 2)
     self.sizer.Add(self.panels_buttons, 1, wx.EXPAND|wx.ALL, 2)
 
-    self.onglets.General(_("General"))
+    #self.onglets.General(_("General"))
     self.onglets.Internet(_("Internet"))
-    self.onglets.Wine(_("Environment"))
-    self.onglets.System(_("System"))
+    #self.onglets.Wine(_("Environment"))
+    #self.onglets.System(_("System"))
     self.onglets.Plugins(_("Plugins"))
-    if len(sys.argv) > 1:
-   	self.onglets.SetSelection(int(sys.argv[1]))
+    try:
+		self.onglets.SetSelection(onglet)
+    except:
+		pass
 
     self.panelFenp.SetSizer(self.sizer)
     self.panelFenp.SetAutoLayout(True)
@@ -434,7 +443,7 @@ class MainWindow(wx.Frame):
     wx.EVT_BUTTON(self, wx.ID_CLOSE, self.app_Close)
 
   def app_Close(self, event):
-    exit(0)
+    self.Destroy()
 
   def apply_settings(self, event):
     #Navigateur
@@ -467,18 +476,5 @@ class MainWindow(wx.Frame):
     self.env_chaine = "DESKTOP="+self.desk+"\nWINEVERSION="+self.onglets.WineVersion.GetValue()
     open(Variables.playonlinux_rep+"/configurations/options/env",'w').write(self.env_chaine)
     wx.MessageBox(_("You must restart PlayOnLinux for the changes to take effect."), "PlayOnLinux", wx.OK)
-    sys.exit(0)
-class PlayOnLinuxApp(wx.App):
-   def OnInit(self):
-	self.frame = MainWindow(None, -1, _("PlayOnLinux Settings"))
-        self.SetTopWindow(self.frame)
-	self.frame.Center(wx.BOTH)
-       	self.frame.Show(True)
-        return True
+    self.Destroy()
 
-
-lng.Lang()
-app = PlayOnLinuxApp()
-app.MainLoop()
-
-sys.exit(0)
